@@ -30,6 +30,11 @@
 **  al.c: assembly line library implementation
 */
 
+/* include optional Autoconf header */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
